import java.awt.*;
import java.awt.event.*;
import java.net.*;

import javax.swing.*;

import com.coyotegulch.jisp.*;

public class AboutJispDialog extends JDialog
{
    private class ActionClose extends AbstractAction
    {
        public void actionPerformed(ActionEvent event)
        {
            m_this.dispose();
        }
    }
    
    // management
    JDialog      m_this = this;
    
    // GUI components
    JTextArea     m_license;
    JButton       m_close;
    JLabel        m_logo;
            
    // contruction helper
    private void createFields()
    {
        m_license = new JTextArea(15,40);
        m_license.setEditable(false);
        m_license.setLineWrap(true);
        m_license.setWrapStyleWord(true);
        m_license.setText(Jisp.LICENSE);
        
        m_close = new JButton("Close");
        m_close.addActionListener(new ActionClose());
        
        m_logo = new JLabel();
        URL iconUrl = ResourceAnchor.class.getClassLoader().getResource("JispLogo.png");
        m_logo.setIcon(new ImageIcon(iconUrl));
    }
    
    static void addToBag(Container cont, Component comp, GridBagConstraints gbc, GridBagLayout lay)
    {
        lay.setConstraints(comp,gbc);
        cont.add(comp);
    }

    private void buildForm(boolean readonly)
    {
        // create interface
        Container content = getContentPane();
        content.setLayout(new BorderLayout());

        // panel to hold controls        
        JPanel fieldPanel = new JPanel();
        
        // create grid bag layout        
        GridBagLayout gridbag = new GridBagLayout(); 
        fieldPanel.setLayout(gridbag);
        fieldPanel.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));

        GridBagConstraints gbc = new GridBagConstraints();
        
        gbc.weightx   = GridBagConstraints.RELATIVE;
        gbc.weighty   = GridBagConstraints.RELATIVE;
        gbc.fill      = GridBagConstraints.BOTH;
        
        // add input file components
        gbc.gridwidth  = GridBagConstraints.RELATIVE;
        gbc.gridheight = 5;
        gbc.weighty    = 1.0;
        addToBag(fieldPanel,m_logo,gbc,gridbag);
        
        gbc.gridwidth  = GridBagConstraints.REMAINDER;
        gbc.gridheight = 1;
        gbc.weighty    = GridBagConstraints.RELATIVE;
        addToBag(fieldPanel,new JLabel(" "),gbc,gridbag);
        addToBag(fieldPanel,new JLabel(" Version " + Jisp.VERSION),gbc,gridbag);
        addToBag(fieldPanel,new JLabel(" Copyright 1996-2003 Scott Robert Ladd"),gbc,gridbag);
        addToBag(fieldPanel,new JLabel(" All rights reserved."),gbc,gridbag);
        addToBag(fieldPanel,new JLabel(" "),gbc,gridbag);

        gbc.gridheight = 1;
        addToBag(fieldPanel,new JLabel(" "),gbc,gridbag);
        addToBag(fieldPanel,new JLabel("License Agreement:",JLabel.CENTER),gbc,gridbag);
        
        gbc.gridwidth  = GridBagConstraints.REMAINDER;
        m_license.setCaretPosition(0);
        m_license.setBorder(BorderFactory.createEtchedBorder());
        JScrollPane scroller = new JScrollPane(m_license);
        scroller.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));
        addToBag(fieldPanel,scroller,gbc,gridbag);

        // buttons
        JPanel buttonPanel = new JPanel();
        buttonPanel.setLayout(new FlowLayout(FlowLayout.RIGHT));
        buttonPanel.add(m_close);
        
        // add panels to content panel
        content.add(fieldPanel, BorderLayout.CENTER);
        content.add(buttonPanel,BorderLayout.SOUTH);
        pack();
    }
    
    // constructor
    public AboutJispDialog(JFrame owner) throws HeadlessException
    {
        // construct base class; true means modal
        super(owner, "About Jisp", true);
        
        // create fields
        createFields();
        
        // build form
        buildForm(false);
    }

}
