import java.io.*;
import java.text.*;

import com.coyotegulch.jisp.*;

public class JispLoadTest
{
    // build a database, in a separate thread    
    private static final String s_nameInput      = "zipcodes.txt";
    private static final String s_nameCityData   = "JispLoadTest.database";
    private static final String s_nameCityIndex1 = "JispLoadTest.btree";
    private static final DecimalFormat s_countForm = new DecimalFormat("00000");
    
    static void loadTest(int order)
    {
        try
        {
            System.out.println("\n<< LOAD TEST >>");
            System.out.println("testing with order = " + order);
                            
            // delete old files
            System.out.println("deleting old files");
            File killit = new File(s_nameCityData);
            
            if (killit.exists())
                killit.delete();
    
            killit = new File(s_nameCityIndex1);
            
            if (killit.exists())
                killit.delete();
                
            // create database
            System.out.println("initializing database");
            IndexedObjectDatabase database = new IndexedObjectDatabase(s_nameCityData,true);
            
            System.out.println("initializing index");
            BTreeIndex index1 = new BTreeIndex(s_nameCityIndex1,BTreeIndex.computeOrder(43000,4),new ZipKey(),false);
            database.attachIndex(index1);
            
            // flag to break out of loops if an exception is thrown
            boolean broken = false;
    
            // counter
            long counter = 0;
    
            // open text file
            BufferedReader reader = null;
            reader = new BufferedReader(new FileReader(s_nameInput));
            
            long startTime = System.currentTimeMillis();
            System.out.println("starting timing loop");
            System.out.print("importing record #: 00000");
        
            // while we have data to read...
            while (reader.ready())
            {
                // read a line
                String line = reader.readLine();

                // skip short lines    
                if (line.length() < 1)
                    continue;
    
                // count it
                ++counter;
                System.out.print("\b\b\b\b\b" + s_countForm.format(counter));
    
                // extract ZIP
                String textZIP = "";
    
                int i;
                for (i = 0; (line.charAt(i) != ','); ++i)
                    textZIP += line.charAt(i);
    
                int zip = Integer.valueOf(textZIP).intValue();
    
                // extract city name
                ++i;
    
                String city = line.substring(i);
    
                // find state
                String state = FindStateByZip.findState(zip);
    
                // write the record (we only have one index, but we still need the key array!
                KeyObject [] keyArray = new KeyObject[2];
                keyArray[0] = new ZipKey(zip);
                keyArray[1] = new CityStateKey(new String(city + state).toUpperCase());
    
                DBRecord record = new DBRecord(city,state,zip);
    
                database.write(keyArray,record);
            }

            System.out.println("\ndone\n\nimport time: " + (System.currentTimeMillis() - startTime));
        }
        catch (Throwable t)
        {
            t.printStackTrace();
        }
    }
    
    static void readTest()
    {
        try
        {
            System.out.println("---- Output phase -----");
            
            // open an output text file
            System.out.println("creating output file");
            File csvName = new File("JispLoadTest.csv");
            
            if (csvName.exists())
                csvName.delete();
            
            PrintWriter csvFile = new PrintWriter(new FileOutputStream(csvName));

            // open database                
            System.out.println("opening database");
            IndexedObjectDatabase database = new IndexedObjectDatabase(s_nameCityData,false);
            BTreeIndex index1 = new BTreeIndex(s_nameCityIndex1);
            database.attachIndex(index1);

            // create an iterator
            System.out.println("creating iterator");
            BTreeIterator iterator = new BTreeIterator(index1);
            
            long startTime = System.currentTimeMillis();
            System.out.println("starting timing loop");
            System.out.print("exporting record #: 00000");

            // counter
            long counter = 0;
    
            // while we have data to read...
            do
            {
                DBRecord rec = (DBRecord)database.read(iterator);

                if (rec != null)
                {
                    ZipKey key = (ZipKey)iterator.getKey();
                    csvFile.println(key.m_key + "," + rec.m_city + "," + rec.m_state);
                    csvFile.flush();
    
                    // count it
                    ++counter;
                    System.out.print("\b\b\b\b\b" + s_countForm.format(counter));
                }
            }
            while (iterator.moveNext());

            System.out.println("\ndone\n\nexport time: " + (System.currentTimeMillis() - startTime));
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
            
        System.out.println(">>> DONE <<<\n");
    }

    // main entry point
    public static void main(String[] args)
    {
        String javaVersion = System.getProperty("java.version");

        if (javaVersion.compareTo("1.3.0") < 0)
        {
            System.err.println("iLibraries requires a version 1.4.0 or higher JVM");
            System.exit(1);
        }

        // determine the order of the B-tree index            
        for (int order = 8; order <= 256; order *= 2)
        {
            loadTest(order);
            readTest();
        }
    }
}

