//-----------------------------------------------------------------------
//  Java Indexed Serialization Package
//  ----------------------------------
//  ZipKey.java
//-----------------------------------------------------------------------
//
//  COPYRIGHT NOTICE, DISCLAIMER, and LICENSE:
//  
//  If you modify this file, you may insert additional notices
//  immediately following this sentence.
//  
//  Copyright 1996-2002 Scott Robert Ladd.
//  All rights reserved, except as noted herein.
//  
//  This computer program source file is supplied "AS IS". Scott Robert
//  Ladd (hereinafter referred to as "Author") disclaims all warranties,
//  expressed or implied, including, without limitation, the warranties
//  of merchantability and of fitness for any purpose. The Author
//  assumes no liability for direct, indirect, incidental, special,
//  exemplary, or consequential damages, which may result from the use
//  of this software, even if advised of the possibility of such damage.
//  
//  The Author hereby grants anyone permission to use, copy, modify, and
//  distribute this source code, or portions hereof, for any purpose,
//  without fee, subject to the following restrictions:
//  
//      1. The origin of this source code must not be misrepresented.
//  
//      2. Altered versions must be plainly marked as such and must not
//         be misrepresented as being the original source.
//  
//      3. This Copyright notice may not be removed or altered from any
//         source or altered source distribution.
//  
//  The Author specifically permits (without fee) and encourages the use
//  of this source code for entertainment, education, or decoration. If
//  you use this source code in a product, acknowledgment is not required
//  but would be appreciated.
//  
//  Acknowledgement:
//      This license is based on the wonderful simple license that
//      accompanies libpng.
//
//-----------------------------------------------------------------------
//  For more information on this software package, please visit
//  Scott's web site, Coyote Gulch Productions, at:
//
//      http://www.coyotegulch.com
//-----------------------------------------------------------------------

import java.io.*; 
import com.coyotegulch.jisp.*;

public class ZipKey extends KeyObject
{
    public int m_key;

    public ZipKey(int key_value)
    {
        m_key = key_value;
    }

    public ZipKey()
    {
        m_key = 0;
    }

    public int compareTo(KeyObject key)
    {
        if (key instanceof ZipKey)
        {
            long comp = m_key - ((ZipKey)key).m_key;

            if (comp == 0)
                return KEY_EQUAL;
            else
                if (comp < 0)
                    return KEY_LESS;
                else
                    return KEY_MORE;
        }
        else
            return KEY_ERROR;
    }

    public KeyObject makeNullKey()
    {
        ZipKey nullKey = new ZipKey();
        nullKey.m_key = 0xFFFFFFFF;
        return nullKey;
    }

    public void writeExternal(ObjectOutput out) throws IOException
    {
        out.writeObject(new Integer(m_key));
    }

    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException
    {
        m_key = ((Integer)(in.readObject())).intValue();
    }

    public int intValue()
    {
        return m_key;
    }

    public String toString()
    {
        return Integer.toString(m_key);
    }
    
    public boolean equals(Object obj)
    {
        if ((obj != null) && (obj instanceof ZipKey))
            return (m_key == ((ZipKey)obj).m_key);
        else
            return false;
    }
    
    public int hashCode()
    {
        return m_key; // new Integer(m_key).hashCode();
    }
}
